@@ -32,66 +32,68 @@ sub _return_max {
     $value > $max ? $max : $value;
 }
 
-plugin 'APIDocs', enable => 'CORS';
+plugin 'Swagger', enable => 'CORS';
 plugin 'Logger', outputs => [['Screen', min_level => 'debug']];
 
 resource user => sub {
-    params [
+    desc 'List users';
+    params(
         optional => { name => 'start', type => Int, default => 0, desc => 'Pager start' },
         optional => { name => 'count', type => Int, default => 10, desc => 'Pager count' },
-    ],
-    desc => 'List users',
-    get => sub {
+    );
+    get sub {
         my $params = shift;
         my @users = UseCase::User::list(%$params);
         { data => paginate(\@users, $params) }
     };
 
-    desc 'List all users',
-    get => 'all' => sub {
+    desc 'List all users';
+    get 'all' => sub {
         my $params = shift;
         my @users = UseCase::User::list(%$params);
         { data => \@users }
     };
 
-    params [
+    desc 'Create new user';
+    params(
         required => { name => 'name', type => Str, desc => 'User name' },
         required => { name => 'password', type => Str, desc => 'User password' },
         optional => { name => 'email', type => Str, default => undef, desc => 'User email' },
-    ],
-    desc => 'Create new user',
-    post => sub {
+    );
+    post sub {
         my $params = shift;
         { success => UseCase::User::create(%$params) }
     };
 
-    route_param id => Int,
-    sub {
-        desc 'Show user',
-        get => sub {
+    params(
+        requires => { name => 'id', type => Int },
+    );
+    route_param id => sub {
+        desc 'Show user';
+        get sub {
             my $params = shift;
             { data => UseCase::User::show($params->{id}) }
         };
 
-        params [
+        desc 'Edit user';
+        params(
             optional => { name => 'password', type => Str, desc => 'User password' },
             optional => { name => 'email', type => Str, desc => 'User email' },
-        ],
-        desc => 'Edit user',
-        put => sub {
+        );
+        put sub {
             my $params = shift;
             { data => UseCase::User::edit($params->{id}, %$params) }
         };
 
         resource bump => sub {
-            desc 'Get bumps count',
-            get => sub {
+            desc 'Get bumps count';
+            get sub {
                 my $params = shift;
                 { data => UseCase::User::show($params->{id})->{bumped} }
             };
 
-            desc 'Bump user',
-            put => sub {
+            desc 'Bump user';
+            put sub {
                 my $params = shift;
                 { success => UseCase::User::bump($params->{id}) }
             };
@@ -100,47 +102,49 @@ resource user => sub {
 };
 
 resource host => sub {
-    params [
+    desc 'List hosts';
+    params(
         optional => { name => 'start', type => Int, default => 0, desc => 'Pager start' },
         optional => { name => 'count', type => Int, default => 10, desc => 'Pager count' },
-    ],
-    desc => 'List hosts',
-    get => sub {
+    );
+    get sub {
         my $params = shift;
         my @hosts = UseCase::Host::list(%$params);
         { data => paginate(\@hosts, $params) }
     };
 
-    params [
+    desc 'Create new host';
+    params(
         required => { name => 'name', type => Str, desc => 'Host name' },
         required => { name => 'user_id', type => Int, desc => 'Host owner' },
         optional => { name => 'state', type => Str, desc => 'Host state' }
-    ],
-    desc => 'Create new host',
-    post => sub {
+    );
+    post sub {
         my $params = shift;
         { success => UseCase::Host::create(%$params) }
     };
 
-    route_param id => Int,
-    sub {
-        desc 'Show host',
-        get => sub {
+    params(
+        requires => { name => 'id', type => Int }
+    );
+    route_param id => sub {
+        desc 'Show host';
+        get sub {
             my $params = shift;
             { data => UseCase::Host::show($params->{id}) }
         };
 
-        params [
+        desc 'Edit host';
+        params(
             required => { name => 'state', type => Str, desc => 'Host state' },
-        ],
-        desc => 'Edit host',
-        put => sub {
+        );
+        put sub {
             my $params = shift;
             { data => UseCase::Host::edit($params->{id}, %$params) }
         };
 
-        desc 'Delete host',
-        del => sub {
+        desc 'Delete host';
+        del sub {
             my $params = shift;
             { success => UseCase::Host::delete($params->{id}) }
         }
