@@ -11,7 +11,7 @@ use Raisin::Response;
 use Raisin::Routes;
 use Raisin::Util;
 
-our $VERSION = '0.4003';
+our $VERSION = '0.5000';
 
 sub new {
     my ($class, %args) = @_;
@@ -55,14 +55,9 @@ sub add_route {
 
 # Resource description
 sub resource_desc {
-    my ($self, $resource) = @_;
-    $resource =~ s#^/##msx;
-    $self->{resource_desc}{$resource};
-}
-
-sub add_resource_desc {
-    my ($self, %params) = @_;
-    $self->{resource_desc}{ $params{resource} } = $params{desc};
+    my ($self, $path, $desc) = @_;
+    $self->{resource_desc}{$path} = $desc if $desc;
+    $self->{resource_desc}{$path};
 }
 
 # Hooks
@@ -269,7 +264,7 @@ Raisin - REST-like API web micro-framework for Perl.
     use warnings;
 
     use Raisin::API;
-    use Types::Standard qw(Int Str);
+    use Types::Standard qw(Any Int Str);
 
     my %USERS = (
         1 => {
@@ -284,17 +279,17 @@ Raisin - REST-like API web micro-framework for Perl.
         },
     );
 
-    plugin 'APIDocs', enable => 'CORS';
+    plugin 'Swagger', enable => 'CORS';
     api_format 'json';
 
-    desc 'Actions on users',
-    resource => user => sub {
-        desc 'List users',
-        params => [
+    desc 'Actions on users';
+    resource user => sub {
+        desc 'List users';
+        params(
             optional => { name => 'start', type => Int, default => 0, desc => 'Pager (start)' },
             optional => { name => 'count', type => Int, default => 10, desc => 'Pager (count)' },
-        ],
-        get => sub {
+        );
+        get sub {
             my $params = shift;
 
             my @users
@@ -309,21 +304,21 @@ Raisin - REST-like API web micro-framework for Perl.
             { data => \@slice }
         };
 
-        desc 'List all users at once',
-        get => 'all' => sub {
+        desc 'List all users at once';
+        get 'all' => sub {
             my @users
                 = map { { id => $_, %{ $USERS{$_} } } }
                   sort { $a <=> $b } keys %USERS;
             { data => \@users }
         };
 
-        desc 'Create new user',
-        params => [
+        desc 'Create new user';
+        params(
             requires => { name => 'name', type => Str, desc => 'User name' },
             requires => { name => 'password', type => Str, desc => 'User password' },
             optional => { name => 'email', type => Str, default => undef, regex => qr/.+\@.+/, desc => 'User email' },
-        ],
-        post => sub {
+        );
+        post sub {
             my $params = shift;
 
             my $id = max(keys %USERS) + 1;
@@ -332,28 +327,27 @@ Raisin - REST-like API web micro-framework for Perl.
             { success => 1 }
         };
 
-        desc 'Actions on the user',
-        params => [
+        desc 'Actions on the user';
+        params(
             requires => { name => 'id', type => Int, desc => 'User ID' },
-        ],
-        route_param => 'id',
-        sub {
-            desc 'Show user',
-            get => sub {
+        );
+        route_param 'id' => sub {
+            desc 'Show user';
+            get sub {
                 my $params = shift;
                 $USERS{ $params->{id} };
             };
 
-            desc 'Delete user',
-            del => sub {
+            desc 'Delete user';
+            del sub {
                 my $params = shift;
                 { success => delete $USERS{ $params->{id} } };
             };
 
-            desc 'NOP',
-            put => sub { 'nop' };
+            desc 'NOP';
+            put sub { 'nop' };
         };
-    }
+    };
 
     run;
 
@@ -363,6 +357,17 @@ Raisin is a REST-like API web micro-framework for Perl.
 It's designed to run on Plack, providing a simple DSL to easily develop RESTful APIs.
 It was inspired by L<Grape|https://github.com/intridea/grape>.
 
+=head1 BACKWARD COMPATIBILITY
+
+Since version C<0.5000> C<Raisin> was migrated to the new API syntax.
+
+You could still use an old style API for a while by passing
+an C<-old> key to the C<Raisin::API>.
+
+    use Raisin::API '-old';
+
+See examples for more information.
+
 =head1 KEYWORDS
 
 =head2 resource
@@ -375,44 +380,28 @@ Adds a route to application.
 
 Define a route parameter as a namespace C<route_param>.
 
-    route_param id => Int, sub { ... };
+    route_param id => sub { ... };
 
 =head2 del, get, patch, post, put
 
 It's a shortcuts to C<route> restricted to the corresponding HTTP method.
 
-Each method can consists of this parameters:
-
-=over
-
-=item * desc - optional only if didn't start from C<desc> keyword, required otherwise;
-
-=item * params - optional only if didn't start from C<params> keyword, required otherwise;
-
-=item * path - optional;
-
-=item * subroutine - required;
-
-=back
-
-Where only C<subroutine> is required.
-
     get sub { 'GET' };
 
     del 'all' => sub { 'OK' };
 
-    params [
+    params(
         requires => { name => 'id', type => Int },
         optional => { name => 'key', type => Str },
-    ],
-    get => sub { 'GET' };
+    );
+    get sub { 'GET' };
 
-    params [
+    desc 'Put data';
+    params(
         required => { name => 'id', type => Int },
         optional => { name => 'name', type => Str },
-    ],
-    desc => 'Put data',
-    put => 'all' => sub {
+    );
+    put 'all' => sub {
         'PUT'
     };
 
@@ -421,8 +410,8 @@ Where only C<subroutine> is required.
 Can be applied to C<resource> or any of HTTP method to add description
 for operation or for resource.
 
-    desc 'Some action',
-    put => sub { ... }
+    desc 'Some action';
+    put sub { ... };
 
     desc 'Some operations group',
     resource => 'user' => sub { ... }
@@ -430,12 +419,17 @@ for operation or for resource.
 =head2 params
 
 Here you can define validations and coercion options for your parameters.
-Can be applied to any HTTP method to describe parameters.
+Can be applied to any HTTP method and/or C<route_param> to describe parameters.
 
-    params => [
+    params(
         requires => { name => 'key', type => Str }
-    ],
-    get => sub { ... }
+    );
+    get sub { ... };
+
+    params(
+        requires => { name => 'id', type => Int, desc => 'User ID' },
+    );
+    route_param 'id' => sub { ... };
 
 For more see L<Raisin/Validation-and-coercion>.
 
@@ -582,11 +576,11 @@ You can define validations and coercion options for your parameters using a para
 Parameters can be C<requires> and C<optional>. C<optional> parameters can have a
 default value.
 
-    params [
+    params(
         requires => { name => 'name', type => Str },
         optional => { name => 'number', type => Int, default => 10 },
-    ],
-    get => sub {
+    );
+    get sub {
         my $params = shift;
         "$params->{number}: $params->{name}";
     };
@@ -768,12 +762,12 @@ Verbose output with route parameters:
 
 L<Swagger|https://github.com/wordnik/swagger-core> compatible API documentations.
 
-    plugin 'APIDocs';
+    plugin 'Swagger';
 
 Documentation will be available on C<http://E<lt>urlE<gt>/api-docs> URL.
 So you can use this URL in Swagger UI.
 
-For more see L<Raisin::Plugin::APIDocs>.
+For more see L<Raisin::Plugin::Swagger>.
 
 =head1 MIDDLEWARE
 
@@ -835,8 +829,8 @@ application is deployed:
 
     my $dancer = sub {
         setting appdir => '/home/dotcloud/current';
-        load_app "My::App";
-        Dancer::App->set_running_app("My::App");
+        load_app 'My::App';
+        Dancer::App->set_running_app('My::App');
         my $env = shift;
         Dancer::Handler->init_request_headers($env);
         my $req = Dancer::Request->new(env => $env);
@@ -844,7 +838,7 @@ application is deployed:
     };
 
     builder {
-        mount "/" => $dancer;
+        mount '/' => $dancer;
         mount '/api/rest' => RaisinApp->new;
     };
 
